@@ -30,6 +30,7 @@ class Plugin(object):
         self._args = None
         self._flags = None
         self._centrify_url = None
+        self._centrify_domain = "my.idaptive.app"
         self._defaults = {}
         self._defaults_modified = False
 
@@ -82,6 +83,7 @@ class Plugin(object):
         :return: None
         """
         self._session.headers.update({"X-CENTRIFY-NATIVE-CLIENT": "True"})
+        self._session.headers.update({"X-IDAP-NATIVE-CLIENT": "True"})
         self._session.headers.update({"CONTENT-TYPE": "application/json"})
         self._session.headers.update({"CACHE-CONTROL": "no-cache"})
         self._session.headers.update({"User-Agent": "Cloudtoken {}".format(get_distribution("cloudtoken").version)})
@@ -105,11 +107,14 @@ class Plugin(object):
         normal URL based off tenant id.
         :return: Centrify URL.
         """
+        if self._get_default("domain_name"):
+            self._centrify_domain = self._get_default("domain_name")
+
         if self._get_default("vanity_id"):
             logger.debug("Vanity ID found in configuration.")
-            self._centrify_url = "https://{}.my.centrify.com".format(self._get_default("vanity_id"))
+            self._centrify_url = "https://{}.{}".format(self._get_default("vanity_id"), self._centrify_domain)
         else:
-            start_url = "https://{}.my.centrify.com/Security/StartAuthentication".format(self._get_default("tenant_id"))
+            start_url = "https://{}.{}/Security/StartAuthentication".format(self._get_default("tenant_id"), self._centrify_domain)
             start_payload = {"User": self._args.username, "Version": "1.0", "TenantId": self._get_default("tenant_id")}
 
             start_result = self.do_json_api_post(start_url, start_payload)
@@ -118,7 +123,7 @@ class Plugin(object):
                 self._centrify_url = "https://{}".format(start_result["Result"]["PodFqdn"])
                 logger.debug("Centrify redirecting us to {}".format(self._centrify_url))
             else:
-                self._centrify_url = "https://{}.my.centrify.com".format(self._get_default("tenant_id"))
+                self._centrify_url = "https://{}.{}".format(self._get_default("tenant_id"), self._centrify_domain)
 
         logger.debug("Using Centrify URL {}".format(self._centrify_url))
         return self._centrify_url
